@@ -2,17 +2,18 @@ from __future__ import annotations
 
 import sys
 from collections.abc import Mapping
-from dataclasses import dataclass
+from dataclasses import InitVar, dataclass
+from typing import Dict, List, Optional, Tuple, Type, Union
+
+import xmltodict
+
+from local_tuya.domoticz.units import UnitId
 
 if sys.version_info < (3, 8):
     from importlib_metadata import metadata as pkg_metadata
 else:
     from importlib.metadata import metadata as pkg_metadata
 
-from typing import Dict, List, Tuple, Union, cast
-
-import xmltodict
-
 XML = Union[str, Dict[str, "XML"], List["XML"]]
 
 
@@ -65,6 +66,10 @@ class Parameter:
         )
 
 
+def get_package_metadata(package: str) -> Mapping[str, str]:
+    return pkg_metadata(package)  # type: ignore
+
+
 @dataclass
 class PluginMetadata:
     # Name that will appear in the hardware dropdown list.
@@ -78,8 +83,10 @@ class PluginMetadata:
     wiki_link: str = ""
     external_link: str = ""
     parameters: Tuple[Parameter, ...] = ()
+    # Add unit ids enum to enable unit selection through plugin params.
+    unit_ids: InitVar[Optional[Type[UnitId]]] = None
 
-    def __post_init__(self):
+    def __post_init__(self, unit_ids: Optional[Type[UnitId]]):
         self.parameters = (
             Parameter(field="Username", label="Device ID", required=True),
             Parameter(field="Address", label="Device IP address", required=True),
@@ -88,20 +95,37 @@ class PluginMetadata:
                 field="Password", label="Device local key", required=True, password=True
             ),
             *self.parameters,
+            *(
+                (
+                    Parameter(
+                        field="Mode5", label="Included units", default=unit_ids.names()
+                    ),
+                )
+                if unit_ids
+                else ()
+            ),
+            Parameter(
+                field="Mode6",
+                label="Debug",
+                options=(
+                    Option(label="No", value="0", default=True),
+                    Option(label="Yes", value="1"),
+                ),
+            ),
         )
 
     def definition(self) -> str:
-        package_metadata = cast(Mapping, pkg_metadata(self.package))
+        package_metadata = get_package_metadata(self.package)
         xml = {
             "plugin": _filter_xml_dict(
                 {
                     "@key": self.package,
                     "@name": self.name,
                     "@author": package_metadata.get("Author", "unknown"),
-                    "@version": package_metadata.get("Version", "1.0.0"),
-                    "@wikilink": self.wiki_link
+                    "@version": "{version:s}",
+                    "@wikilink": self.wiki_link,
+                    "@externallink": self.external_link
                     or package_metadata.get("Home-page", ""),
-                    "@externallink": self.external_link,
                     "description": self.description,
                     "params": {
                         "param": [p.to_xml_dict() for p in self.parameters],
